@@ -26,7 +26,6 @@
 typedef enum {
 	NUMBER_TYPE_RATIONAL,
 	NUMBER_TYPE_FLOAT,
-	NUMBER_TYPE_INFINITY,
 	NUMBER_TYPE_PLUS_INFINITY,
 	NUMBER_TYPE_MINUS_INFINITY
 } NumberType;
@@ -47,28 +46,28 @@ typedef enum {
 * Implimented using GNU MP and MPFR.
  */
 class Number {
-	
+
 	private:
 
 	protected:
-	
+
 		void testInteger();
 		bool testErrors(int error_level = 1) const;
 		bool testFloatResult(bool allow_infinite_result = true, int error_level = 1, bool test_integer = true);
-		void setPrecisionAndApproximateFrom(const Number &o);
 
 		mpq_t r_value;
-		mpfr_t f_value;
-		
+		mpfr_t fu_value;
+		mpfr_t fl_value;
+
 		Number *i_value;
-		
+
 		NumberType n_type;
-		
+
 		bool b_approx, b_imag;
 		int i_precision;
 
 	public:
-	
+
 		/**
 		* Constructs a number initialized as zero.
  		*/
@@ -79,7 +78,7 @@ class Number {
 		* @param number Text string to read number from.
 		* @param po Options for parsing the text string.
  		*/
-		Number(string number, const ParseOptions &po = default_parse_options);
+		Number(std::string number, const ParseOptions &po = default_parse_options);
 		/**
 		* Constructs a rational number.
 		*
@@ -93,13 +92,13 @@ class Number {
  		*/
 		Number(const Number &o);
 		virtual ~Number();
-		
-		void set(string number, const ParseOptions &po = default_parse_options);
+
+		void set(std::string number, const ParseOptions &po = default_parse_options);
 		void set(long int numerator, long int denominator = 1, long int exp_10 = 0, bool keep_precision = false, bool keep_imag = false);
-		void setInfinity(bool keep_precision = false);
-		void setPlusInfinity(bool keep_precision = false);
-		void setMinusInfinity(bool keep_precision = false);
-		void setFloat(double d_value);
+		void setPlusInfinity(bool keep_precision = false, bool keep_imag = false);
+		void setMinusInfinity(bool keep_precision = false, bool keep_imag = false);
+		void setFloat(long double d_value);
+		bool setInterval(const Number &nr_lower, const Number &nr_upper, bool keep_precision = false);
 
 		void setInternal(const mpz_t &mpz_value, bool keep_precision = false, bool keep_imag = false);
 		void setInternal(mpz_srcptr mpz_value, bool keep_precision = false, bool keep_imag = false);
@@ -113,16 +112,28 @@ class Number {
 		void clear(bool keep_precision = false);
 		void clearReal();
 		void clearImaginary();
-		
+
 		const mpq_t &internalRational() const;
-		const mpfr_t &internalFloat() const;
+		const mpfr_t &internalUpperFloat() const;
+		const mpfr_t &internalLowerFloat() const;
 		mpq_t &internalRational();
-		mpfr_t &internalFloat();
+		mpfr_t &internalUpperFloat();
+		mpfr_t &internalLowerFloat();
 		Number *internalImaginary() const;
 		void markAsImaginaryPart(bool is_imag = true);
 		const NumberType &internalType() const;
 		bool setToFloatingPoint();
-		
+		void precisionToInterval();
+		bool intervalToPrecision(long int min_precision = 2);
+		void intervalToMidValue();
+		void splitInterval(unsigned int nr_of_parts, std::vector<Number> &v) const;
+		bool getCentralInteger(Number &nr_int, bool *b_multiple = NULL, std::vector<Number> *v = NULL) const;
+		bool mergeInterval(const Number &o, bool set_to_overlap = false);
+		void setUncertainty(const Number &o, bool to_precision = false);
+		void setRelativeUncertainty(const Number &o, bool to_precision = false);
+		Number uncertainty() const;
+		Number relativeUncertainty() const;
+
 		double floatValue() const;
 		/**
 		* Converts a number to an integer. If the number does not represent an integer it will rounded using round().
@@ -133,8 +144,9 @@ class Number {
 		int intValue(bool *overflow = NULL) const;
 		unsigned int uintValue(bool *overflow = NULL) const;
 		long int lintValue(bool *overflow = NULL) const;
+		long long int llintValue() const;
 		unsigned long int ulintValue(bool *overflow = NULL) const;
-		
+
 		/** Returns true if the number is approximate.
 		*
  		* @return true if the number is approximate.
@@ -145,41 +157,46 @@ class Number {
  		* @return true if the number has an approximate representation.
  		*/
 		bool isFloatingPoint() const;
+
+		void setPrecisionAndApproximateFrom(const Number &o);
+
+		bool isInterval(bool ignore_imag = true) const;
+		bool imaginaryPartIsInterval() const;
+
 		/** Defines the number as approximate or exact.
 		*
  		* @param is_approximate If the number shall be regarded as approximate.
  		*/
 		void setApproximate(bool is_approximate = true);
-		
+
 		/** Returns the.precision of the number.
 		*
  		* @return Precision of the number or -1 if the number is exact or the precision has not been set.
  		*/
-		int precision() const;
+		int precision(int calculate_from_interval = 0) const;
 		void setPrecision(int prec);
-		
+
 		bool isUndefined() const;
 		/** Returns true if the number is infinity, plus infinity or minus infinity.
 		*
  		* @return true if the number is infinite.
  		*/
-		bool isInfinite() const;
-		/** Returns true if the number is infinity, if the number is plus or minus infinity (which is not known).
-		*
- 		* @return true if the number is infinity.
- 		*/
-		bool isInfinity() const;
+		bool isInfinite(bool ignore_imag = true) const;
 		/** Returns true if the number is plus infinity.
 		*
  		* @return true if the number is plus infinity.
  		*/
-		bool isPlusInfinity() const;
+		bool isPlusInfinity(bool ignore_imag = false) const;
 		/** Returns true if the number is minus infinity.
 		*
  		* @return true if the number is minus infinity.
  		*/
-		bool isMinusInfinity() const;
-		
+		bool isMinusInfinity(bool ignore_imag = false) const;
+
+		bool includesInfinity(bool ignore_imag = false) const;
+		bool includesPlusInfinity() const;
+		bool includesMinusInfinity() const;
+
 		/** Returns the real part of the number if it is complex, or a copy if it is real.
 		*
  		* @return true if the real part of a complex number.
@@ -194,6 +211,8 @@ class Number {
 		Number denominator() const;
 		Number complexNumerator() const;
 		Number complexDenominator() const;
+		Number lowerEndPoint(bool include_imag = false) const;
+		Number upperEndPoint(bool include_imag = false) const;
 
 		void operator = (const Number &o);
 		void operator = (long int i);
@@ -213,7 +232,7 @@ class Number {
 		Number operator && (const Number &o) const;
 		Number operator || (const Number &o) const;
 		Number operator ! () const;
-		
+
 		void operator *= (const Number &o);
 		void operator /= (const Number &o);
 		void operator += (const Number &o);
@@ -224,21 +243,30 @@ class Number {
 		void operator += (long int i);
 		void operator -= (long int i);
 		void operator ^= (long int i);
-		
+
 		bool operator == (const Number &o) const;
 		bool operator != (const Number &o) const;
+		bool operator < (const Number &o) const;
+		bool operator <= (const Number &o) const;
+		bool operator > (const Number &o) const;
+		bool operator >= (const Number &o) const;
+		bool operator < (long int i) const;
+		bool operator <= (long int i) const;
+		bool operator > (long int i) const;
+		bool operator >= (long int i) const;
 		bool operator == (long int i) const;
 		bool operator != (long int i) const;
-		
+
 		bool bitAnd(const Number &o);
 		bool bitOr(const Number &o);
 		bool bitXor(const Number &o);
 		bool bitNot();
+		bool bitCmp(unsigned int bits);
 		bool bitEqv(const Number &o);
 		bool shiftLeft(const Number &o);
 		bool shiftRight(const Number &o);
 		bool shift(const Number &o);
-		
+
 		bool hasRealPart() const;
 		bool hasImaginaryPart() const;
 		bool isComplex() const;
@@ -248,6 +276,7 @@ class Number {
 		bool isReal() const;
 		bool isFraction() const;
 		bool isZero() const;
+		bool isNonZero() const;
 		bool isOne() const;
 		bool isTwo() const;
 		bool isI() const;
@@ -258,16 +287,23 @@ class Number {
 		bool isPositive() const;
 		bool isNonPositive() const;
 		bool realPartIsNegative() const;
+		bool realPartIsNonNegative() const;
 		bool realPartIsPositive() const;
+		bool realPartIsNonZero() const;
+		bool realPartIsRational() const;
 		bool imaginaryPartIsNegative() const;
 		bool imaginaryPartIsPositive() const;
+		bool imaginaryPartIsNonNegative() const;
+		bool imaginaryPartIsNonPositive() const;
+		bool imaginaryPartIsNonZero() const;
 		bool hasNegativeSign() const;
 		bool hasPositiveSign() const;
 		bool equalsZero() const;
-		bool equals(const Number &o) const;
+		bool equals(const Number &o, bool allow_interval = false, bool allow_infinite = false) const;
 		bool equals(long int i) const;
-		bool equalsApproximately(const Number &o, int prec) const;
-		ComparisonResult compare(const Number &o) const;
+		int equalsApproximately(const Number &o, int prec) const;
+		ComparisonResult compare(const Number &o, bool ignore_imag = false) const;
+		ComparisonResult compareAbsolute(const Number &o, bool ignore_imag = false) const;
 		ComparisonResult compare(long int i) const;
 		ComparisonResult compareApproximately(const Number &o, int prec = EQUALS_PRECISION_LOWEST) const;
 		ComparisonResult compareImaginaryParts(const Number &o) const;
@@ -281,13 +317,22 @@ class Number {
 		bool isGreaterThanOrEqualTo(long int i) const;
 		bool isLessThanOrEqualTo(long int i) const;
 		bool isEven() const;
+		bool numeratorIsGreaterThan(long int i) const;
+		bool numeratorIsLessThan(long int i) const;
+		bool numeratorEquals(long int i) const;
+		bool denominatorIsGreaterThan(long int i) const;
+		bool denominatorIsLessThan(long int i) const;
+		bool denominatorEquals(long int i) const;
+		bool denominatorIsGreater(const Number &o) const;
+		bool denominatorIsLess(const Number &o) const;
+		bool denominatorIsEqual(const Number &o) const;
 		bool denominatorIsEven() const;
 		bool denominatorIsTwo() const;
 		bool numeratorIsEven() const;
 		bool numeratorIsOne() const;
 		bool numeratorIsMinusOne() const;
 		bool isOdd() const;
-		
+
 		int integerLength() const;
 
 		/** Add to the number (x+o).
@@ -330,6 +375,10 @@ class Number {
  		* @return true if the operation was successful.
  		*/
 		bool raise(const Number &o, bool try_exact = true);
+		bool sqrt();
+		bool cbrt();
+		bool root(const Number &o);
+		bool allroots(const Number &o, std::vector<Number> &roots);
 		/** Multiply the number with a power of ten (x*10^o).
 		*
 		* @param o Number to raise 10 by.
@@ -357,7 +406,7 @@ class Number {
  		* @return true if the operation was successful.
  		*/
 		bool square();
-		
+
 		/** Negate the number (-x).
 		*
  		* @return true if the operation was successful.
@@ -366,20 +415,21 @@ class Number {
 		void setNegative(bool is_negative);
 		bool abs();
 		bool signum();
-		bool round(const Number &o);
+		bool round(const Number &o, bool halfway_to_even = true);
 		bool floor(const Number &o);
 		bool ceil(const Number &o);
 		bool trunc(const Number &o);
 		bool mod(const Number &o);
 		bool isIntegerDivisible(const Number &o) const;
 		bool isqrt();
-		bool round();
+		bool isPerfectSquare() const;
+		bool round(bool halfway_to_even = true);
 		bool floor();
 		bool ceil();
-		bool trunc();	
-		bool frac();		
+		bool trunc();
+		bool frac();
 		bool rem(const Number &o);
-		
+
 		bool smod(const Number &o);
 		bool irem(const Number &o);
 		bool irem(const Number &o, Number &q);
@@ -392,7 +442,7 @@ class Number {
 		void setTrue(bool is_true = true);
 		void setFalse();
 		void setLogicalNot();
-		
+
 		/** Set the number to e, the base of natural logarithm, calculated with the current default precision.
  		*/
 		void e(bool use_cached_number = true);
@@ -410,7 +460,7 @@ class Number {
  		* @return true if the calculation was successful.
  		*/
 		bool zeta();
-		
+
 		bool gamma();
 		bool digamma();
 		bool airy();
@@ -418,7 +468,7 @@ class Number {
 		bool erfc();
 		bool besselj(const Number &o);
 		bool bessely(const Number &o);
-		
+
 		bool sin();
 		bool asin();
 		bool sinh();
@@ -429,7 +479,8 @@ class Number {
 		bool acosh();
 		bool tan();
 		bool atan();
-		bool atan2(const Number &o);
+		bool atan2(const Number &o, bool allow_zero = false);
+		bool arg();
 		bool tanh();
 		bool atanh();
 		bool ln();
@@ -438,25 +489,37 @@ class Number {
 		bool lambertW();
 		bool gcd(const Number &o);
 		bool lcm(const Number &o);
-		
+
+		bool polylog(const Number &o);
+		bool igamma(const Number &o);
+		bool expint();
+		bool logint();
+		bool sinint();
+		bool sinhint();
+		bool cosint();
+		bool coshint();
+
 		bool factorial();
 		bool multiFactorial(const Number &o);
 		bool doubleFactorial();
 		bool binomial(const Number &m, const Number &k);
-		bool factorize(vector<Number> &factors);
-		
+		bool factorize(std::vector<Number> &factors);
+
 		void rand();
+		void randn();
 		void intRand(const Number &ceil);
-	
-		bool add(const Number &o, MathOperation op); 
 
-		string printNumerator(int base = 10, bool display_sign = true, BaseDisplay base_display = BASE_DISPLAY_NORMAL, bool lower_case = false) const;
-		string printDenominator(int base = 10, bool display_sign = true, BaseDisplay base_display = BASE_DISPLAY_NORMAL, bool lower_case = false) const;
-		string printImaginaryNumerator(int base = 10, bool display_sign = true, BaseDisplay base_display = BASE_DISPLAY_NORMAL, bool lower_case = false) const;
-		string printImaginaryDenominator(int base = 10, bool display_sign = true, BaseDisplay base_display = BASE_DISPLAY_NORMAL, bool lower_case = false) const;
+		bool add(const Number &o, MathOperation op);
+
+		std::string printNumerator(int base = 10, bool display_sign = true, BaseDisplay base_display = BASE_DISPLAY_NORMAL, bool lower_case = false) const;
+		std::string printDenominator(int base = 10, bool display_sign = true, BaseDisplay base_display = BASE_DISPLAY_NORMAL, bool lower_case = false) const;
+		std::string printImaginaryNumerator(int base = 10, bool display_sign = true, BaseDisplay base_display = BASE_DISPLAY_NORMAL, bool lower_case = false) const;
+		std::string printImaginaryDenominator(int base = 10, bool display_sign = true, BaseDisplay base_display = BASE_DISPLAY_NORMAL, bool lower_case = false) const;
+
+		std::string print(const PrintOptions &po = default_print_options, const InternalPrintStruct &ips = top_ips) const;
 
-		string print(const PrintOptions &po = default_print_options, const InternalPrintStruct &ips = top_ips) const;
-	
 };
 
+std::ostream& operator << (std::ostream &os, const Number&);
+
 #endif
